==> org.eclipse.riena.sample.app.client.mail.source_2.0.0.v20100615_2_0_0.jar: org/eclipse/riena/sample/app/client/mail/OpenViewHandler.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.sample.app.client.mail;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.IHandler;

import org.eclipse.riena.navigation.ApplicationNodeManager;
import org.eclipse.riena.navigation.IApplicationNode;
import org.eclipse.riena.navigation.IModuleGroupNode;
import org.eclipse.riena.navigation.IModuleNode;
import org.eclipse.riena.navigation.NavigationNodeId;

/**
 * Creates a new module group with an associated message view.
 */
public class OpenViewHandler extends AbstractHandler implements IHandler {

	private int count = 0;

	public Object execute(ExecutionEvent event) {
		IApplicationNode node = ApplicationNodeManager.getApplicationNode();
		IModuleGroupNode group = (IModuleGroupNode) node.findNode(new NavigationNodeId(Application.ID_GROUP_MBOXES));
		String title = "me@this.com (" + ++count + ")"; //$NON-NLS-1$ //$NON-NLS-2$
		IModuleNode moduleAccount1 = NodeFactory.createModule(new NavigationNodeId("account", Integer.toString(count)), //$NON-NLS-1$
				title, group);
		NodeFactory.createSubMobule(
				new NavigationNodeId("Inbox", Integer.toString(count)), "Inbox", moduleAccount1, View.ID); //$NON-NLS-1$ //$NON-NLS-2$
		NodeFactory.createSubMobule(
				new NavigationNodeId("Drafts", Integer.toString(count)), "Drafts", moduleAccount1, View.ID); //$NON-NLS-1$ //$NON-NLS-2$
		NodeFactory.createSubMobule(
				new NavigationNodeId("Sent", Integer.toString(count)), "Sent", moduleAccount1, View.ID); //$NON-NLS-1$ //$NON-NLS-2$
		return null;
	}
}

==> org.eclipse.riena.sample.app.client.mail.source_3.0.0.v20110614_3_0_0_0.jar: org/eclipse/riena/sample/app/client/mail/OpenViewHandler.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2011 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.sample.app.client.mail;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.IHandler;

import org.eclipse.riena.navigation.ApplicationNodeManager;
import org.eclipse.riena.navigation.IApplicationNode;
import org.eclipse.riena.navigation.IModuleGroupNode;
import org.eclipse.riena.navigation.IModuleNode;
import org.eclipse.riena.navigation.NavigationNodeId;

/**
 * Creates a new module group with an associated message view.
 */
public class OpenViewHandler extends AbstractHandler implements IHandler {

	private int count = 0;

	public Object execute(final ExecutionEvent event) {
		final IApplicationNode node = ApplicationNodeManager.getApplicationNode();
		final IModuleGroupNode group = (IModuleGroupNode) node.findNode(new NavigationNodeId(
				Application.ID_GROUP_MBOXES));
		final String title = "me@this.com (" + ++count + ")"; //$NON-NLS-1$ //$NON-NLS-2$
		final IModuleNode moduleAccount1 = NodeFactory.createModule(
				new NavigationNodeId("account", Integer.toString(count)), //$NON-NLS-1$
				title, group);
		NodeFactory.createSubMobule(
				new NavigationNodeId("Inbox", Integer.toString(count)), "Inbox", moduleAccount1, View.ID); //$NON-NLS-1$ //$NON-NLS-2$
		NodeFactory.createSubMobule(
				new NavigationNodeId("Drafts", Integer.toString(count)), "Drafts", moduleAccount1, View.ID); //$NON-NLS-1$ //$NON-NLS-2$
		NodeFactory.createSubMobule(
				new NavigationNodeId("Sent", Integer.toString(count)), "Sent", moduleAccount1, View.ID); //$NON-NLS-1$ //$NON-NLS-2$
		return null;
	}
}
